@@ -156,11 +156,13 @@ pub enum LogTo {
 /// A command to run in a subprocess and options for how it is run.
 ///
 /// Some notable trait implementations:
-/// - Derives `Clone`, `Debug`, `Eq`, and `PartialEq`
-/// - `Default` (see docstrings for each field for what the
+/// - Derives [`Clone`], [`Debug`], [`Eq`], and [`PartialEq`]
+/// - [`Default`] (see docstrings for each field for what the
 ///   corresponding default is)
 /// - `From<&Command> for std::process::Command` to convert to a
 ///   [`std::process::Command`]
+///
+/// [`Debug`]: std::fmt::Debug
 #[derive(Clone, Debug, Eq, PartialEq)]
 pub struct Command {
     /// Program path.
@@ -210,32 +212,42 @@ pub struct Command {
 }
 
 impl Command {
-    /// Make a new Command with the given program.
+    /// Make a new `Command` with the given program.
     ///
     /// All other fields are set to the defaults.
-    pub fn new<S: AsRef<OsStr>>(program: S) -> Command {
-        Command {
+    pub fn new<S: AsRef<OsStr>>(program: S) -> Self {
+        Self {
             program: program.as_ref().into(),
             ..Default::default()
         }
     }
 
-    /// Make a new Command with the given program and args.
+    /// Make a new `Command` with the given program and args.
     ///
     /// All other fields are set to the defaults.
-    pub fn with_args<I, S1, S2>(program: S1, args: I) -> Command
+    pub fn with_args<I, S1, S2>(program: S1, args: I) -> Self
     where
         S1: AsRef<OsStr>,
         S2: AsRef<OsStr>,
         I: IntoIterator<Item = S2>,
     {
-        Command {
+        Self {
             program: program.as_ref().into(),
             args: args.into_iter().map(|arg| arg.as_ref().into()).collect(),
             ..Default::default()
         }
     }
 
+    /// Create a `Command` from a whitespace-separated string. If the
+    /// string is empty or all whitespace, `None` is returned.
+    ///
+    /// This function does not do unquoting or escaping.
+    pub fn from_whitespace_separated_str(s: &str) -> Option<Self> {
+        let mut parts = s.split_whitespace();
+        let program = parts.next()?;
+        Some(Self::with_args(program, parts))
+    }
+
     /// Append a single argument.
     pub fn add_arg<S: AsRef<OsStr>>(&mut self, arg: S) -> &mut Self {
         self.args.push(arg.as_ref().into());
@@ -410,7 +422,7 @@ impl Command {
 
 impl Default for Command {
     fn default() -> Self {
-        Command {
+        Self {
             program: PathBuf::new(),
             args: Vec::new(),
             dir: None,
